@@ -1,3 +1,4 @@
+import os.path as op
 import re
 
 
@@ -5,8 +6,19 @@ def cmp(val):
     return bool(re.match('0x[0-9A-Fa-f]+\-0x[0-9A-Fa-f]+', val))
 
 
+class PackageRequiredException(Exception):
+
+    def __init__(self, message):
+        self.message = message
+
+    def __str__(self):
+        return repr(self.message)
+
+
 class BaseExt(object):
 
+    CHARACTER_SET_PATH = op.realpath(op.join(op.dirname(__file__), '..', 'charmaps'))
+
     @staticmethod
     def convert_to_list_of_unicodes(string):
         codes = string.split(',')
