@@ -4,14 +4,15 @@ from fontaine.ext.base import BaseExt, PackageRequiredException
 try:
     import icu
 except ImportError:
-    package = ("[PyICU](https://pypi.python.org/pypi/PyICU) to"
-               "enable [feature], perhaps with: pip install pyicu")
+    package = ("PyICU <https://pypi.python.org/pypi/PyICU> to "
+               "enable CLDR related features, perhaps with: pip install pyicu")
     raise PackageRequiredException('Please install %s' % package)
 
 
 class Extension(BaseExt):
 
     extension_name = 'cldr'
+    description = 'CLDR collection'
 
     @staticmethod
     def to_charmap(locale):
